@@ -34,6 +34,7 @@ SPATIAL_REFERENCE = 'spatialReference'
 WKID = 'wkid'
 LATEST_WKID = 'latestWkid'
 WKT = 'wkt'
+FID = 'FID'
 GEOMETRY_TYPE = 'geometryType'
 GEOMETRY = 'geometry'
 ATTRIBUTES = 'attributes'
@@ -72,6 +73,8 @@ RELATION_PARAM = 'relationParam'
 MAX_RECORD_COUNT = 'maxRecordCount'
 RETURN_Z = 'returnZ'
 RETURN_M = 'returnM'
+HAS_Z = 'hasZ'
+HAS_M = 'hasM'
 RETURN_TRUE_CURVES = 'returnTrueCurves'
 RETURN_IDS_ONLY = 'returnIdsOnly'
 RESULT_RECORD_COUNT = 'resultRecordCount' # added at 10.3
@@ -92,9 +95,12 @@ ATTACHMENT = 'attachment'
 ATTACHMENTS = 'attachments'
 ATTACHMENT_GROUPS = 'attachmentGroups'
 ATTACHMENT_INFOS = 'attachmentInfos'
+CAN_APPLY_EDITS_WITH_ATTACHMENTS = 'canApplyEditsWithAttachments'
+SUPPORTS_APPLY_EDITS_WITH_GLOBALIDS = 'supportsApplyEditsWithGlobalIds'
 STATUS_URL = 'statusUrl'
 URL_WITH_TOKEN = 'urlWithToken' # not in ArcGIS REST API, custom key
 ADD_ATTACHMENT_RESULT = 'addAttachmentResult'
+ADD_ATTACHMENT_RESULTS = 'addAttachmentResults'
 UPDATE_ATTACHMENT_RESULT = 'updateAttachmentResult'
 DELETE_ATTACHMENT_RESULTS = 'deleteAttachmentResults'
 RELATED_RECORD_GROUPS = 'relatedRecordGroups'
@@ -280,6 +286,7 @@ CURVE_RINGS = 'curveRings'
 CURVE_PATHS = 'curvePaths'
 X = 'x'
 Y = 'y'
+Z = 'z'
 COPY_RUNTIME_GDB_TO_FILE_GDB = 'CopyRuntimeGdbToFileGdb'
 DEFAULT_VALUE = 'defaultValue'
 SQL_GLOBAL_ID_EXP = 'NEWID() WITH VALUES'
@@ -365,23 +372,30 @@ FTYPES = {DATE_FIELD:'DATE',
           GLOBALID: 'GUID'}
 
 SKIP_FIELDS = {
-          RASTER_FIELD:'RASTER',
-          BLOB_FIELD: 'BLOB'}
+    RASTER_FIELD:'RASTER',
+    BLOB_FIELD: 'BLOB'
+}
 
-EXTRA ={OID: 'OID@',
-        SHAPE: 'SHAPE@'}
+EXTRA = {
+    OID: 'OID@',  
+    SHAPE: 'SHAPE@'
+}
 
-G_DICT = {ESRI_POLYGON: 'Polygon',
-          ESRI_POINT: 'Point',
-          ESRI_POLYLINE: 'Polyline',
-          ESRI_MULTIPOINT: 'Multipoint',
-          ESRI_ENVELOPE:'Envelope'}
+G_DICT = {
+    ESRI_POLYGON: 'Polygon',
+    ESRI_POINT: 'Point',
+    ESRI_POLYLINE: 'Polyline',
+    ESRI_MULTIPOINT: 'Multipoint',
+    ESRI_ENVELOPE:'Envelope'
+}
 
-GEOM_DICT = {RINGS: ESRI_POLYGON,
-             PATHS: ESRI_POLYLINE,
-             POINTS: ESRI_MULTIPOINT,
-             X: ESRI_POINT,
-             Y: ESRI_POINT}
+GEOM_DICT = {
+    RINGS: ESRI_POLYGON,
+    PATHS: ESRI_POLYLINE,
+    POINTS: ESRI_MULTIPOINT,
+    X: ESRI_POINT,
+    Y: ESRI_POINT
+}
 
 FIELD_STRUCT = {ALIAS: NULL,
     NAME: NULL,
@@ -390,11 +404,13 @@ FIELD_STRUCT = {ALIAS: NULL,
 }
 
 
-JSON_DICT = {'rings': 'esriGeometryPolygon',
-             'paths': 'esriGeometryPolyline',
-             'points': 'esriGeometryMultipoint',
-             'x': 'esriGeometryPoint',
-             'y': 'esriGeometryPoint'}
+JSON_DICT = {
+    'rings': 'esriGeometryPolygon',
+    'paths': 'esriGeometryPolyline',
+    'points': 'esriGeometryMultipoint',
+    'x': 'esriGeometryPoint',
+    'y': 'esriGeometryPoint'
+}
 
 JSON_CODE = {v:k for k,v in six.iteritems(JSON_DICT)}
 
@@ -404,7 +420,7 @@ GEOM_CODE = {v:k for k,v in six.iteritems(GEOM_DICT)}
 BASE_PATTERN = 'http*://*/rest/services*'
 PORTAL_BASE_PATTERN = 'http*://*/sharing/rest*'
 PORTAL_SERVICES_PATTERN = 'http*://*/sharing/servers/*/rest/services/*'
-VERSION = '2.0.1'
+VERSION = '2.1'
 PACKAGE_NAME = 'restapi'
 USER_AGENT = '{}/{} (Python)'.format(PACKAGE_NAME, VERSION)
 GET = 'GET'
@@ -417,3 +433,10 @@ try:
     JSON_PATH = os.path.dirname(__file__)
 except:
     JSON_PATH = os.path.abspath(os.path.dirname(sys.argv[0]))
+
+GEOJSON_POINT = 'Point'
+GEOJSON_MULTIPOINT = 'MultiPoint'
+GEOJSON_LINESTRING = 'LineString'
+GEOJSON_MULTI_LINESTRING = 'MultiLineString'
+GEOJSON_POLYGON = 'Polygon'
+GEOJSON_MULTIPOLYGON = 'MultiPolygon'
