@@ -6,6 +6,7 @@ import time
 import json
 import sys
 from .rest_utils import *
+from .conversion import *
 
 import six
 from six.moves import range
@@ -22,7 +23,7 @@ def find_ws_type(path):
     """Determines output workspace (feature class if not FileSystem).
         returns a tuple of workspace path and type.
 
-    Arg:
+    Args:
         path: Path for workspace.
     """
 
@@ -53,11 +54,12 @@ class Geometry(BaseGeometry):
         geometryType: The type of geometry.
         json: JSON object.
     """
+    _native_format = ESRI_JSON_FORMAT
 
     def __init__(self, geometry, **kwargs):
         """Converts geometry input to restapi.Geometry object.
 
-        Arg:
+        Args:
             geometry: Input geometry.  Can be arcpy.Geometry(), shapefile/feature
                 class, or JSON.
 
@@ -115,6 +117,12 @@ class Geometry(BaseGeometry):
                     raise ValueError('Not a valid geometry input!')
 
         if isinstance(geometry, dict):
+            # first check for geojson
+            if is_geojson(geometry):
+                self.geometryType = GEOJSON_GEOMETRY_MAPPING.get(geometry.get(TYPE))
+                self.json = geojson_to_arcgis(geometry)
+                return
+
             if FEATURES in geometry:
                 d = geometry[FEATURES][0]
                 if GEOMETRY in d:
@@ -170,6 +178,14 @@ class Geometry(BaseGeometry):
             else:
                 self.geometryType = NULL_GEOMETRY
         self.hasCurves = CURVE_PATHS in self.json or CURVE_RINGS in self.json
+        
+    @property
+    def _native_json(self):
+        return geojson_to_arcgis(self.json) if is_geojson(self.json) else self.json
+
+    @property
+    def _native_type(self):
+        return self.geometryType
 
     def envelope(self):
         """Return an envelope from shape."""
@@ -212,9 +228,7 @@ class Geometry(BaseGeometry):
 
     def asShape(self):
         """Returns JSON as arcpy.Geometry() object."""
-        if self.geometryType != ESRI_ENVELOPE:
-            return arcpy.AsShape(self.json, True)
-        else:
+        if self.geometryType == ESRI_ENVELOPE:
             ar = arcpy.Array([
                 arcpy.Point(self.json[XMIN], self.json[YMAX]),
                 arcpy.Point(self.json[XMAX], self.json[YMAX]),
@@ -222,6 +236,8 @@ class Geometry(BaseGeometry):
                 arcpy.Point(self.json[XMIN], self.json[YMIN])
             ])
             return arcpy.Polygon(ar, arcpy.SpatialReference(self.spatialReference))
+        else:
+            return arcpy.AsShape(self._native_json, True)
 
     def toPolygon(self):
         """Returns a polygon that is converted from geometry."""
@@ -381,7 +397,7 @@ class GeocodeHandler(object):
     def __init__(self, geocodeResult):
         """Geocode response object handler
 
-        Arg:
+        Args:
             geocodeResult: GeocodeResult object.
         """
 
